==> org.openl.rules-5.22.6-sources.jar: org/openl/rules/enumeration/CountriesEnum.java <==
package org.openl.rules.enumeration;

public enum CountriesEnum {

    AL("Albania"),
    DZ("Algeria"),
    AR("Argentina"),
    AU("Australia"),
    AT("Austria"),
    BH("Bahrain"),
    BY("Belarus"),
    BE("Belgium"),
    BO("Bolivia"),
    BA("Bosnia And Herzegowina"),
    BR("Brazil"),
    BG("Bulgaria"),
    CA("Canada"),
    CL("Chile"),
    CN("China"),
    CO("Colombia"),
    CR("Costa Rica"),
    HR("Croatia"),
    CY("Cyprus"),
    CZ("Czech Republic"),
    DK("Denmark"),
    DO("Dominican Republic"),
    EC("Ecuador"),
    EG("Egypt"),
    SV("El Salvador"),
    EE("Estonia"),
    FI("Finland"),
    FR("France"),
    DE("Germany"),
    GR("Greece"),
    GT("Guatemala"),
    HN("Honduras"),
    HK("Hong Kong"),
    HU("Hungary"),
    IS("Iceland"),
    IN("India"),
    ID("Indonesia"),
    IQ("Iraq"),
    IE("Ireland"),
    IL("Israel"),
    IT("Italy"),
    JP("Japan"),
    JO("Jordan"),
    KW("Kuwait"),
    LV("Latvia"),
    LB("Lebanon"),
    LT("Lithuania"),
    LU("Luxembourg"),
    MK("Macedonia"),
    MY("Malaysia"),
    MT("Malta"),
    MX("Mexico"),
    MA("Morocco"),
    NL("Netherlands"),
    NZ("New Zealand"),
    NI("Nicaragua"),
    NO("Norway"),
    OM("Oman"),
    PA("Panama"),
    PY("Paraguay"),
    PE("Peru"),
    PH("Philippines"),
    PL("Poland"),
    PT("Portugal"),
    PR("Puerto Rico"),
    QA("Qatar"),
    RO("Romania"),
    RU("Russian Federation"),
    SA("Saudi Arabia"),
    CS("Serbia And Montenegro"),
    SG("Singapore"),
    SK("Slovakia"),
    SI("Slovenia"),
    ZA("South Africa"),
    ES("Spain"),
    SD("Sudan"),
    SE("Sweden"),
    CH("Switzerland"),
    SY("Syrian Arab Republic"),
    TW("Taiwan"),
    TH("Thailand"),
    TN("Tunisia"),
    TR("Turkey"),
    UA("Ukraine"),
    AE("United Arab Emirates"),
    GB("United Kingdom"),
    US("United States"),
    UY("Uruguay"),
    VE("Venezuela"),
    VN("Viet Nam"),
    YE("Yemen");

    private final String displayName;

    private CountriesEnum(String displayName) {
        this.displayName = displayName;
    }

    @Override
    public String toString() {
        return displayName;
    }

    public static CountriesEnum fromString(String displayName) {
        for (CountriesEnum v : CountriesEnum.values()) {
            if (displayName.equalsIgnoreCase(v.displayName)) {
                return v;
            }
        }

        throw new IllegalArgumentException("No constant with displayName " + displayName + " found");
    }
}

==> org.openl.rules-5.26.5-sources.jar: org/openl/rules/enumeration/CountriesEnum.java <==
package org.openl.rules.enumeration;

public enum CountriesEnum {

    AE("United Arab Emirates"),
    AL("Albania"),
    AR("Argentina"),
    AS("American Samoa"),
    AT("Austria"),
    AU("Australia"),
    BA("Bosnia And Herzegowina"),
    BE("Belgium"),
    BG("Bulgaria"),
    BH("Bahrain"),
    BO("Bolivia"),
    BR("Brazil"),
    BY("Belarus"),
    CA("Canada"),
    CH("Switzerland"),
    CK("Cook Islands"),
    CL("Chile"),
    CN("China"),
    CO("Colombia"),
    CR("Costa Rica"),
    CS("Serbia And Montenegro"),
    CY("Cyprus"),
    CZ("Czech Republic"),
    DE("Germany"),
    DK("Denmark"),
    DO("Dominican Republic"),
    DZ("Algeria"),
    EC("Ecuador"),
    EE("Estonia"),
    EG("Egypt"),
    ES("Spain"),
    FI("Finland"),
    FJ("Fiji"),
    FR("France"),
    GB("United Kingdom"),
    GR("Greece"),
    GT("Guatemala"),
    HK("Hong Kong"),
    HN("Honduras"),
    HR("Croatia"),
    HU("Hungary"),
    ID("Indonesia"),
    IE("Ireland"),
    IL("Israel"),
    IN("India"),
    IQ("Iraq"),
    IS("Iceland"),
    IT("Italy"),
    JO("Jordan"),
    JP("Japan"),
    KW("Kuwait"),
    LB("Lebanon"),
    LT("Lithuania"),
    LU("Luxembourg"),
    LV("Latvia"),
    MA("Morocco"),
    MK("Macedonia"),
    MT("Malta"),
    MX("Mexico"),
    MY("Malaysia"),
    NI("Nicaragua"),
    NL("Netherlands"),
    NO("Norway"),
    NZ("New Zealand"),
    OM("Oman"),
    PA("Panama"),
    PE("Peru"),
    PG("Papua New Guinea"),
    PH("Philippines"),
    PL("Poland"),
    PR("Puerto Rico"),
    PT("Portugal"),
    PY("Paraguay"),
    QA("Qatar"),
    RO("Romania"),
    RU("Russian Federation"),
    SA("Saudi Arabia"),
    SB("Solomon Islands"),
    SD("Sudan"),
    SE("Sweden"),
    SG("Singapore"),
    SI("Slovenia"),
    SK("Slovakia"),
    SV("El Salvador"),
    SY("Syrian Arab Republic"),
    TH("Thailand"),
    TN("Tunisia"),
    TO("Tonga"),
    TR("Turkey"),
    TW("Taiwan"),
    UA("Ukraine"),
    US("United States"),
    UY("Uruguay"),
    VE("Venezuela"),
    VN("Viet Nam"),
    VU("Vanuatu"),
    WS("Samoa"),
    YE("Yemen"),
    ZA("South Africa");

    private final String displayName;

    CountriesEnum(String displayName) {
        this.displayName = displayName;
    }

    @Override
    public String toString() {
        return displayName;
    }

    public static CountriesEnum fromString(String displayName) {
        for (CountriesEnum v : CountriesEnum.values()) {
            if (displayName.equalsIgnoreCase(v.displayName)) {
                return v;
            }
        }

        throw new IllegalArgumentException(String.format("No constant with displayName '%s' is found.", displayName));
    }
}
